@@ -9,6 +9,6 @@ try:
 
     _version_tuple = tuple(int(x) for x in _version.split("."))
 
-except Exception:
+except Exception:  # pragma: no cover
     _version = "0.0.1"
     _version_tuple = (0, 0, 1)
