@@ -20,10 +20,6 @@ from ..server import StreamCommand
 from ..model import Entry
 from ..exceptions import AuthFailedError
 
-import logging
-
-logger = logging.getLogger(__name__)
-
 
 def load(typ: str, *, make: bool = False, server: bool):
     if typ == "client":
