@@ -9,27 +9,10 @@ import outcome
 import socket
 import os
 from typing import Tuple
+from contextlib import asynccontextmanager, AsyncExitStack
+
 from asyncscope import scope, Scope, main_scope
 
-try:
-    ClosedResourceError = anyio.exceptions.ClosedResourceError
-except AttributeError:
-    ClosedResourceError = anyio.ClosedResourceError
-
-rs = os.environ.get("PYTHONHASHSEED", None)
-if rs is None:
-    import random
-else:  # pragma: no cover
-    import trio._core._run as tcr
-
-    random = tcr._r
-
-try:
-    from contextlib import asynccontextmanager, AsyncExitStack
-except ImportError:  # pragma: no cover
-    from async_generator import asynccontextmanager
-    from async_exit_stack import AsyncExitStack
-
 from .util import (
     attrdict,
     gen_ssl,
@@ -58,6 +41,22 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+try:
+    ClosedResourceError = anyio.exceptions.ClosedResourceError
+except AttributeError:
+    ClosedResourceError = anyio.ClosedResourceError
+
+rs = os.environ.get("PYTHONHASHSEED", None)
+if rs is None:
+    import random
+else:  # pragma: no cover
+    try:
+        import trio._core._run as tcr
+    except ImportError:
+        import random
+    else:
+        random = tcr._r
+
 __all__ = ["NoData", "ManyData", "open_client", "client_scope", "StreamedRequest"]
 
 
@@ -299,8 +298,7 @@ class _SingleReply:
 
 
 class ClientConfig:
-    """Accessor for configuration, possibly stored in DistKV.
-    """
+    """Accessor for configuration, possibly stored in DistKV."""
 
     _changed = None  # pylint
 
@@ -462,8 +460,7 @@ class Client:
                 await sock.send(p)
 
     async def _reader(self, *, evt=None):
-        """Main loop for reading
-        """
+        """Main loop for reading"""
         unpacker = stream_unpacker()
 
         async with anyio.open_cancel_scope():
@@ -482,10 +479,9 @@ class Client:
                     if self._socket is None:
                         break
                     try:
-                        try:
-                            buf = await self._socket.receive_some(4096)
-                        except AttributeError:
-                            buf = await self._socket.receive(4096)
+                        buf = await self._socket.receive(4096)
+                    except anyio.EndOfStream:
+                        raise ServerClosedError("Connection closed by peer")
                     except ClosedResourceError:
                         return  # closed by us
                     if len(buf) == 0:  # Connection was closed.
@@ -587,7 +583,7 @@ class Client:
             # … or maybe … (auth does this)
             async with client._stream("interactive_thing", path=P(':n.foo)) as req:
                 msg = await req.recv()
-                while msg.get(s,"")=="more":
+                while msg.get(s,"") == "more":
                     await foo.send(s="more",value="some data")
                     msg = await req.recv()
                 await foo.send(s="that's all then")
@@ -619,6 +615,9 @@ class Client:
                 await res.aclose()
 
     async def _run_auth(self, auth=None):
+        """
+        As the name implies: process authorization.
+        """
         hello = self._server_init
         sa = hello.get("auth", ())
         if not sa or not sa[0]:
@@ -708,7 +707,7 @@ class Client:
         Retrieve the data at a particular subtree position.
 
         Usage::
-            res = await client.get("foo","bar")
+            res = await client.get(P("foo.bar"))
 
         If you want to update this value, you should retrieve its change chain entry
         so that a competing update can be detected::
@@ -717,6 +716,10 @@ class Client:
             res = await client.set("foo","bar", value=res.value+1, chain=res.chain)
 
         For lower overhead and set-directly-after-get change, nchain may be 1 or 2.
+
+        Arguments:
+            path (Path): the path to update.
+            nchain: set to retrieve the node's chain tag, for later updates.
         """
         if isinstance(path, str):
             raise RuntimeError("You need a path, not a string")
@@ -727,9 +730,10 @@ class Client:
         Set or update a value.
 
         Usage::
-            await client.set("foo","bar", value="baz", chain=None)
+            await client.set(P("foo.bar"), value="baz", chain=None)
 
         Arguments:
+            path (Path): the path to update.
             value: the value to set. Duh. ;-)
             chain: the previous value's change chain. Use ``None`` for new values.
             prev: the previous value. Discouraged; use ``chain`` instead.
@@ -753,17 +757,21 @@ class Client:
             action="set_value", path=path, value=value, iter=False, nchain=nchain, **kw
         )
 
-    def delete(self, path, *, chain=NotGiven, prev=NotGiven, nchain=0):
+    def delete(self, path, *, chain=NotGiven, prev=NotGiven, nchain=0,
+            recursive=False):
         """
         Delete a node.
 
         Usage::
-            await client.delete("foo","bar")
+            await client.delete(P("foo.bar"))
 
         Arguments:
+            path (Path): the path of the entry to remove.
             chain: the previous value's change chain.
             prev: the previous value. Discouraged; use ``chain`` instead.
             nchain: set to retrieve the node's chain, for setting a new value.
+            recursive: delete the whole subtree. Cannot be used with
+                ``chain`` and/or ``prev``.
         """
         if isinstance(path, str):
             raise RuntimeError("You need a path, not a string")
@@ -773,13 +781,14 @@ class Client:
         if chain is not NotGiven:
             kw["chain"] = chain
 
-        return self._request(action="delete_value", path=path, iter=False, nchain=nchain, **kw)
+        return self._request(action="delete_tree" if recursive else "delete_value", path=path, iter=False, nchain=nchain, **kw)
 
     async def list(self, path, *, with_data=False, empty=None, **kw):
         """
         Retrieve the next data level.
 
         Args:
+          path (Path): the path to retrieve the entries from.
           with_data (bool): Return the data along with the keys. Default False.
           empty (bool): Return [names of] empty nodes. Default True if
             with_data is not set.
@@ -803,6 +812,7 @@ class Client:
         if you need a consistent snapshot.
 
         Args:
+          path (Path): the path to retrieve the entries from.
           nchain (int): Length of change chain to add to the results, for updating.
           min_depth (int): min level of nodes to retrieve.
           max_depth (int): max level of nodes to retrieve.
@@ -849,6 +859,7 @@ class Client:
         Return an async iterator of changes to a subtree.
 
         Args:
+          path (Path): the path to monitor entries at.
           fetch (bool): if ``True``, also send the currect state. Be aware
             that this may overlap with processing changes: you may get
             updates before the current state is completely transmitted.
@@ -900,13 +911,12 @@ class Client:
 
     def msg_monitor(self, topic: Tuple[str], raw: bool = False):
         """
-        Return an async iterator of tunneled Serf messages. This receives
+        Return an async iterator of tunneled messages. This receives
         all messages sent using :meth:`msg_send` with the same tag.
 
         Args:
             tag: the topic / "user:" tag to monitor.
                  The first character may not be '+'.
-                 Do not include Serf's "user:" prefix.
             raw: If ``True``, will not try to msgpack-decode incoming
                  messages.
 
@@ -928,17 +938,18 @@ class Client:
 
     def msg_send(self, topic: Tuple[str], data=None, raw: bytes = None):
         """
-        Tunnel a user-tagged message through Serf. This sends the message
+        Tunnel a user-tagged message. This sends the message
         to all active callers of :meth:`msg_monitor` which use the same tag.
 
         Args:
             tag: the "user:" tag to send to.
                  The first character may not be '+'.
-                 Do not include Serf's "user:" prefix.
             data: to-be-encoded data (anything ``msgpack`` can process).
             raw: raw binary data to send, mutually exclusive with ``data``.
         """
         if raw is None:
             return self._request(action="msg_send", topic=topic, data=data)
+        elif data is not None:
+            raise RuntimeError("You can either send raw or non-raw data")
         else:
             return self._request(action="msg_send", topic=topic, raw=raw)
