@@ -222,5 +222,9 @@ class CodeEntry(ClientEntry):
             proc = self._code
             if kw:
                 proc = partial(proc, **kw)
-            return anyio.run_in_thread(proc, *a)
+            try:
+                return anyio.run_in_thread(proc, *a)
+            except AttributeError:
+                return anyio.run_sync_in_worker_thread(proc, *a)
+
         return self._code(*a, **kw)
