@@ -2,15 +2,11 @@
 
 import asyncclick as click
 
-from distkv.util import split_one, NotGiven, yprint, Path
+from distkv.util import split_arg, NotGiven, yprint, Path
 from distkv.auth import loader, gen_auth
 
-import logging
 
-logger = logging.getLogger(__name__)
-
-
-@main.group(short_help="Manage authorization")  # pylint: disable=undefined-variable
+@click.group(short_help="Manage authorization")  # pylint: disable=undefined-variable
 @click.option("-m", "--method", default=None, help="Affect/use this auth method")
 @click.pass_obj
 async def cli(obj, method):
@@ -131,7 +127,7 @@ async def list_user(obj, verbose):
 async def get(obj, ident):
     """Retrieve a user (processed)."""
     lv = loader(await one_auth(obj), "user", make=True, server=False)
-    if obj._DEBUG:
+    if obj.DEBUG:
         lv._length = 16
 
     u = await lv.recv(obj.client, ident, _initial=False)
@@ -157,7 +153,7 @@ async def param(obj, new, ident, type, key, args):  # pylint: disable=redefined-
     """Set user parameters for auth, conversion, etc."""
     auth = await one_auth(obj)
     u = loader(auth, "user", make=True, server=False)
-    if obj._DEBUG:
+    if obj.DEBUG:
         u._length = 16
     # ou = await u.recv(obj.client, ident, _initial=False)  # unused
     res = await obj.client._request(
@@ -182,7 +178,7 @@ async def param(obj, new, ident, type, key, args):  # pylint: disable=redefined-
         kw["key"] = key
 
         for a in args:
-            split_one(a, kw)
+            split_arg(a, kw)
 
         res = await obj.client._request(
             action="set_internal",
@@ -211,7 +207,7 @@ async def mod(obj, ident, args):
 async def add_mod_user(obj, args, modify):
     auth = await one_auth(obj)
     u = loader(auth, "user", make=True, server=False)
-    if obj._DEBUG:
+    if obj.DEBUG:
         u._length = 16
     if modify:
         ou = await u.recv(obj.client, modify, _initial=False)
@@ -219,7 +215,7 @@ async def add_mod_user(obj, args, modify):
     else:
         kw = {}
     for a in args:
-        split_one(a, kw)
+        split_arg(a, kw)
 
     u = u.build(kw, _initial=False)
     if modify is None or u.ident != modify:
