@@ -4,16 +4,12 @@ import time
 import asyncclick as click
 import datetime
 
-from distkv.util import PathLongener, MsgReader, NotGiven, yprint, data_get, P
+from distkv.util import PathLongener, MsgReader, NotGiven, yprint, P
 from distkv.client import StreamedRequest
-from distkv.command import node_attr
-
-import logging
-
-logger = logging.getLogger(__name__)
+from distkv.data import data_get, node_attr, add_dates
 
 
-@main.group(short_help="Manage data.")  # pylint: disable=undefined-variable
+@click.group(short_help="Manage data.")  # pylint: disable=undefined-variable
 async def cli():
     """
     This subcommand accesses the actual user data stored in your DistKV tree.
@@ -38,6 +34,7 @@ async def cli():
 @click.option("-r", "--recursive", is_flag=True, help="Read a complete subtree")
 @click.option("-e", "--empty", is_flag=True, help="Include empty nodes")
 @click.option("-R", "--raw", is_flag=True, help="Print string values without quotes etc.")
+@click.option("-D", "--add-date", is_flag=True, help="Add *_date entries")
 @click.argument("path", nargs=1)
 @click.pass_obj
 async def get(obj, path, **k):
@@ -140,10 +137,15 @@ async def set_(obj, path, value, eval_, last, new, path_, attr):
     if obj.meta:
         yprint(res, stream=obj.stdout)
 
+class nstr:
+    def __new__(cls, val):
+        if val is NotGiven:
+            return val
+        return str(val)
 
 @cli.command(short_help="Delete an entry / subtree")
 @click.argument("path", nargs=1)
-@click.option("-p", "--prev", default=NotGiven, help="Previous value. Deprecated; use 'last'")
+@click.option("-p", "--prev", type=nstr, default=NotGiven, help="Previous value. Deprecated; use 'last'")
 @click.option("-l", "--last", nargs=2, help="Previous change entry (node serial)")
 @click.option("-r", "--recursive", is_flag=True, help="Delete a complete subtree")
 @click.option("--internal", is_flag=True, help="Affect the internal tree. DANGER.")
@@ -168,7 +170,7 @@ async def delete(obj, path, prev, last, recursive, eval_, internal):
         raise click.UsageError("You need to add a value that can be evaluated")
     if recursive:
         if prev is not NotGiven or last:
-            raise click.UsageError("'local' and 'force' are mutually exclusive")
+            raise click.UsageError("You can't use a prev value when deleting recursively.")
         if internal:
             raise click.UsageError("'internal' and 'recursive' are mutually exclusive")
     else:
@@ -199,10 +201,11 @@ async def delete(obj, path, prev, last, recursive, eval_, internal):
 @cli.command()
 @click.option("-s", "--state", is_flag=True, help="Also get the current state.")
 @click.option("-o", "--only", is_flag=True, help="Value only, nothing fancy.")
+@click.option("-D", "--add-date", is_flag=True, help="Add *_date entries")
 @click.argument("path", nargs=1)
 @click.pass_obj
-async def watch(obj, path, state, only):
-    """Watch a DistKV subtree"""
+async def monitor(obj, path, state, only, add_date):
+    """Monitor a DistKV subtree"""
 
     flushing = not state
     path = P(path)
@@ -212,6 +215,8 @@ async def watch(obj, path, state, only):
         path, nchain=obj.meta, fetch=state, max_depth=0 if only else -1
     ) as res:
         async for r in res:
+            if add_date and "value" in r:
+                add_dates(r.value)
             if r.get("state", "") == "uptodate":
                 if only and not seen:
                     # value doesn't exist
@@ -225,10 +230,10 @@ async def watch(obj, path, state, only):
                         continue
                     except AttributeError:
                         # value has been deleted
-                        return
+                        continue
             if flushing:
-                r["time"] = time.monotonic()
-                r["date"] = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+                r["time"] = time.time()
+                r["_time"] = datetime.datetime.now().isoformat(sep=" ", timespec="milliseconds")
             yprint(r, stream=obj.stdout)
             print("---", file=obj.stdout)
             if flushing:
