@@ -1,9 +1,8 @@
 import pytest
 
-from .mock_mqtt import stdtest
+from distkv.mock.mqtt import stdtest
 
-# from .run import run
-# from functools import partial
+from distkv.util import P
 
 import logging
 
@@ -15,9 +14,7 @@ async def test_81_basic(autojump_clock):  # pylint: disable=unused-argument
     async with stdtest(args={"init": 123}) as st:
         async with st.client() as c:
             assert "hoo" not in c.config
-            res = await c.set(
-                ".distkv", "config", "hoo", value={"hello": "there"}, nchain=2
-            )
+            res = await c.set(P(":.distkv.config.hoo"), value={"hello": "there"}, nchain=2)
             await c._config.wait_chain(res.chain)
             assert c.config.hoo["hello"] == "there"
 
